/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;

/* section: NIM_merge_TYPES */
typedef NIM_BOOL tyArray__zl3qUQvo0CT9bJi9b5H7mRkw[65];
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
typedef NU8 tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA;
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef NU8 tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag;
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
typedef NU32 tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU64 tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TDistinctCompare__9bNKHGs63atuMFXnAleTveg;
typedef NU8 tySet_tyEnum_TTypeCmpFlag__72pgRXSg7774cr9aCWVPORw;
typedef NU8 tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw;
typedef NU8 tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU16 tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw;
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_TAliasRequest__BbWVl1Ad9ayM74eg8oBpAfw;
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
static N_INLINE(NIM_BOOL, isAtom__ORlI8o1EUYdPqjuTcBWx1Aast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag, isAssignable__H8ClJSBthN45fIRKmjWHMQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isUnsafeAddr);
static N_INLINE(NIM_BOOL, dontInlineConstant__164nxsacBEejwonWVg9c9aQQtrees)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* cnst);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, compareTypes__oyXq5u7iL4RjsT9bovvTE9cg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* y, tyEnum_TDistinctCompare__9bNKHGs63atuMFXnAleTveg cmp, tySet_tyEnum_TTypeCmpFlag__72pgRXSg7774cr9aCWVPORw flags);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg, getMagic__4W1ZJaFiusqlhViRx9cbM9bw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* op);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lastSon__UPSW0jLTX5qJL51YMUAHgw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw, checkForSideEffects__apZ9c8Nt8WLADYEdQq9beFoA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NIM_BOOL, isRoutine__Ye2MiAptq3GrXxTQeyXNeAast)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__vokyXY9cZDshCSxFKChhG9bg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_NIMCALL(NimStringDesc*, rawNewString)(NI cap);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(void, compileConstraints__ei3y5Hkw3H4CU1JGiutKlw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* p, NimStringDesc** result, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, patternError__5Tflpt1vZ7YgBe0KNn4aLw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw renderFlags);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
static N_INLINE(void, add__wJRzZcEmnPNg9a3PLD2A5IAparampatterns)(NimStringDesc** code, tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA op);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuNormalize)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NI, hashString)(NimStringDesc* s);
static N_INLINE(NimStringDesc*, toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(void, addInt__mftMOxbyu0h4yByfs3sqjA)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__iGg0RIKceRvsmvq8FUHOEw)(NimStringDesc* s, NI first);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);

/* section: NIM_merge_DATA */
STRING_LITERAL(TM__kdeXVhLeMhTeIyOxnAjnxA_2, "illformed AST: ", 15);
STRING_LITERAL(TM__kdeXVhLeMhTeIyOxnAjnxA_4, "/home/runner/work/nightlies/nightlies/nim/compiler/parampattern"
"s.nim", 68);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__kdeXVhLeMhTeIyOxnAjnxA_3 = {((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_4),
((NI) 46),
((NI) 12)}
;
STRING_LITERAL(TM__kdeXVhLeMhTeIyOxnAjnxA_5, "|", 1);
STRING_LITERAL(TM__kdeXVhLeMhTeIyOxnAjnxA_6, "&", 1);
STRING_LITERAL(TM__kdeXVhLeMhTeIyOxnAjnxA_7, "~", 1);
STRING_LITERAL(TM__kdeXVhLeMhTeIyOxnAjnxA_8, "atom", 4);
STRING_LITERAL(TM__kdeXVhLeMhTeIyOxnAjnxA_9, "lit", 3);
STRING_LITERAL(TM__kdeXVhLeMhTeIyOxnAjnxA_10, "sym", 3);
STRING_LITERAL(TM__kdeXVhLeMhTeIyOxnAjnxA_11, "ident", 5);
STRING_LITERAL(TM__kdeXVhLeMhTeIyOxnAjnxA_12, "call", 4);
STRING_LITERAL(TM__kdeXVhLeMhTeIyOxnAjnxA_13, "alias", 5);
STRING_LITERAL(TM__kdeXVhLeMhTeIyOxnAjnxA_14, "noalias", 7);
STRING_LITERAL(TM__kdeXVhLeMhTeIyOxnAjnxA_15, "lvalue", 6);
STRING_LITERAL(TM__kdeXVhLeMhTeIyOxnAjnxA_16, "local", 5);
STRING_LITERAL(TM__kdeXVhLeMhTeIyOxnAjnxA_17, "sideeffect", 10);
STRING_LITERAL(TM__kdeXVhLeMhTeIyOxnAjnxA_18, "nosideeffect", 12);
STRING_LITERAL(TM__kdeXVhLeMhTeIyOxnAjnxA_19, "(", 1);
STRING_LITERAL(TM__kdeXVhLeMhTeIyOxnAjnxA_20, ", ", 2);
STRING_LITERAL(TM__kdeXVhLeMhTeIyOxnAjnxA_21, ")", 1);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__kdeXVhLeMhTeIyOxnAjnxA_22 = {((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_4),
((NI) 101),
((NI) 21)}
;
extern NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
extern TNimType NTI__cNCW9acsSznmEccl1fgQwkw_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__kdeXVhLeMhTeIyOxnAjnxA_23 = {((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_4),
((NI) 108),
((NI) 21)}
;
extern TNimType NTI__G4E4Gxe7oI2Cm03rkiOzQw_;
STRING_LITERAL(TM__kdeXVhLeMhTeIyOxnAjnxA_24, "parameter pattern too complex", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__kdeXVhLeMhTeIyOxnAjnxA_25 = {((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_4),
((NI) 128),
((NI) 19)}
;

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_INLINE(NIM_BOOL, isAtom__ORlI8o1EUYdPqjuTcBWx1Aast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) <= (*n).kind);
	if (!(T1_)) goto LA2_;
	T1_ = ((*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23));
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, dontInlineConstant__164nxsacBEejwonWVg9c9aQQtrees)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* cnst) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NI T5_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = !(((*orig).kind == (*cnst).kind));
	if (!(T2_)) goto LA3_;
	T2_ = ((*cnst).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39) || (*cnst).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37) || (*cnst).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160) || (*cnst).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41) || (*cnst).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T5_ = (NI)0;
	T5_ = len__P89cqdlERShb9alU3iC0yj8wast(cnst);
	T1_ = (((*cnst).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38)) < T5_);
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag, isAssignable__H8ClJSBthN45fIRKmjWHMQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isUnsafeAddr) {
	tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag result;
	result = (tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag)0;
	result = ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 0);
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1):
	{
		{
			NIM_BOOL T4_;
			T4_ = (NIM_BOOL)0;
			T4_ = !(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T4_)) goto LA5_;
			T4_ = ((8388608 &((NU64)1<<((NU)((*(*n).typ).kind)&63U)))!=0);
			LA5_: ;
			if (!T4_) goto LA6_;
			result = ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 1);
		}
		LA6_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kinds;
		{
			if (!isUnsafeAddr) goto LA11_;
			kinds = 2100008;
		}
		goto LA9_;
		LA11_: ;
		{
			kinds = 2336;
		}
		LA9_: ;
		{
			NIM_BOOL T16_;
			T16_ = (NIM_BOOL)0;
			T16_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			if (!(T16_)) goto LA17_;
			T16_ = ((IL64(70368752566272) &((NU64)1<<((NU)((*(*(*n)._kind_4.sym).typ).kind)&63U)))!=0);
			LA17_: ;
			if (!T16_) goto LA18_;
			result = ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 1);
		}
		goto LA14_;
		LA18_: ;
		{
			NIM_BOOL T21_;
			T21_ = (NIM_BOOL)0;
			T21_ = isUnsafeAddr;
			if (!(T21_)) goto LA22_;
			T21_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			LA22_: ;
			if (!T21_) goto LA23_;
			result = ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 1);
		}
		goto LA14_;
		LA23_: ;
		{
			NIM_BOOL T26_;
			NIM_BOOL T27_;
			T26_ = (NIM_BOOL)0;
			T27_ = (NIM_BOOL)0;
			T27_ = isUnsafeAddr;
			if (!(T27_)) goto LA28_;
			T27_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10));
			LA28_: ;
			T26_ = T27_;
			if (!(T26_)) goto LA29_;
			T26_ = dontInlineConstant__164nxsacBEejwonWVg9c9aQQtrees(n, (*(*n)._kind_4.sym).ast);
			LA29_: ;
			if (!T26_) goto LA30_;
			result = ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 1);
		}
		goto LA14_;
		LA30_: ;
		{
			if (!((kinds &((NU32)1<<((NU)((*(*n)._kind_4.sym).kind)&31U)))!=0)) goto LA33_;
			{
				NIM_BOOL T37_;
				NIM_BOOL T38_;
				T37_ = (NIM_BOOL)0;
				T38_ = (NIM_BOOL)0;
				T38_ = !((owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
				if (!(T38_)) goto LA39_;
				T38_ = (owner == (*(*n)._kind_4.sym).owner);
				LA39_: ;
				T37_ = T38_;
				if (!(T37_)) goto LA40_;
				T37_ = !((((*(*n)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3))&63U)))!=0));
				LA40_: ;
				if (!T37_) goto LA41_;
				result = ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 2);
			}
			goto LA35_;
			LA41_: ;
			{
				result = ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 1);
			}
			LA35_: ;
		}
		goto LA14_;
		LA33_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
			if (!((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7))) goto LA45_;
			t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_4.sym).typ, 256);
			{
				if (!((8388608 &((NU64)1<<((NU)((*t).kind)&63U)))!=0)) goto LA49_;
				result = ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 5);
			}
			LA49_: ;
		}
		goto LA14_;
		LA45_: ;
		LA14_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
		t_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273488));
		{
			if (!((IL64(70368758857728) &((NU64)1<<((NU)((*t_2).kind)&63U)))!=0)) goto LA54_;
			result = ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 1);
		}
		goto LA52_;
		LA54_: ;
		{
			NIM_BOOL T57_;
			T57_ = (NIM_BOOL)0;
			T57_ = isUnsafeAddr;
			if (!(T57_)) goto LA58_;
			T57_ = ((*t_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47));
			LA58_: ;
			if (!T57_) goto LA59_;
			result = ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 1);
		}
		goto LA52_;
		LA59_: ;
		{
			result = isAssignable__H8ClJSBthN45fIRKmjWHMQ(owner, (*n)._kind_6.sons->data[((NI) 0)], isUnsafeAddr);
		}
		LA52_: ;
		{
			NIM_BOOL T64_;
			NIM_BOOL T65_;
			T64_ = (NIM_BOOL)0;
			T65_ = (NIM_BOOL)0;
			T65_ = !((result == ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 0)));
			if (!(T65_)) goto LA66_;
			T65_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			LA66_: ;
			T64_ = T65_;
			if (!(T64_)) goto LA67_;
			T64_ = (((*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 20))&63U)))!=0);
			LA67_: ;
			if (!T64_) goto LA68_;
			result = ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 3);
		}
		LA68_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_3;
		t_3 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273488));
		{
			if (!((IL64(70368758857728) &((NU64)1<<((NU)((*t_3).kind)&63U)))!=0)) goto LA73_;
			result = ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 1);
		}
		goto LA71_;
		LA73_: ;
		{
			NIM_BOOL T76_;
			T76_ = (NIM_BOOL)0;
			T76_ = isUnsafeAddr;
			if (!(T76_)) goto LA77_;
			T76_ = ((*t_3).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47));
			LA77_: ;
			if (!T76_) goto LA78_;
			result = ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 1);
		}
		goto LA71_;
		LA78_: ;
		{
			result = isAssignable__H8ClJSBthN45fIRKmjWHMQ(owner, (*n)._kind_6.sons->data[((NI) 0)], isUnsafeAddr);
		}
		LA71_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 60):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T84_;
			T84_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T84_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36275087638308880));
			if (!((134610944 &((NU64)1<<((NU)((*T84_).kind)&63U)))!=0)) goto LA85_;
			result = isAssignable__H8ClJSBthN45fIRKmjWHMQ(owner, (*n)._kind_6.sons->data[((NI) 1)], isUnsafeAddr);
		}
		goto LA82_;
		LA85_: ;
		{
			NIM_BOOL T88_;
			T88_ = (NIM_BOOL)0;
			T88_ = compareTypes__oyXq5u7iL4RjsT9bovvTE9cg((*n).typ, (*(*n)._kind_6.sons->data[((NI) 1)]).typ, ((tyEnum_TDistinctCompare__9bNKHGs63atuMFXnAleTveg) 1), 0);
			if (!T88_) goto LA89_;
			result = isAssignable__H8ClJSBthN45fIRKmjWHMQ(owner, (*n)._kind_6.sons->data[((NI) 1)], isUnsafeAddr);
		}
		goto LA82_;
		LA89_: ;
		LA82_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n0;
		n0 = (*n)._kind_6.sons->data[((NI) 0)];
		{
			if (!((*(*n0).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47))) goto LA94_;
			{
				NIM_BOOL T98_;
				NIM_BOOL T100_;
				T98_ = (NIM_BOOL)0;
				T98_ = isUnsafeAddr;
				if (T98_) goto LA99_;
				T100_ = (NIM_BOOL)0;
				T100_ = ((*n0).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
				if (!(T100_)) goto LA101_;
				T100_ = ((*(*n0)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11));
				LA101_: ;
				T98_ = T100_;
				LA99_: ;
				if (!T98_) goto LA102_;
				result = ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 1);
			}
			goto LA96_;
			LA102_: ;
			{
				result = ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 4);
			}
			LA96_: ;
		}
		goto LA92_;
		LA94_: ;
		{
			result = ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 1);
		}
		LA92_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64):
	{
		result = ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 1);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 67):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46):
	{
		result = isAssignable__H8ClJSBthN45fIRKmjWHMQ(owner, (*n)._kind_6.sons->data[((NI) 0)], isUnsafeAddr);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		{
			tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg T111_;
			T111_ = (tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg)0;
			T111_ = getMagic__4W1ZJaFiusqlhViRx9cbM9bw(n);
			if (!(T111_ == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 5) || T111_ == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 126))) goto LA112_;
			result = isAssignable__H8ClJSBthN45fIRKmjWHMQ(owner, (*n)._kind_6.sons->data[((NI) 1)], isUnsafeAddr);
		}
		goto LA109_;
		LA112_: ;
		{
			NIM_BOOL T115_;
			T115_ = (NIM_BOOL)0;
			T115_ = !(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T115_)) goto LA116_;
			T115_ = ((8388608 &((NU64)1<<((NU)((*(*n).typ).kind)&63U)))!=0);
			LA116_: ;
			if (!T115_) goto LA117_;
			result = ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 1);
		}
		goto LA109_;
		LA117_: ;
		{
			NIM_BOOL T120_;
			NIM_BOOL T121_;
			T120_ = (NIM_BOOL)0;
			T121_ = (NIM_BOOL)0;
			T121_ = isUnsafeAddr;
			if (!(T121_)) goto LA122_;
			T121_ = !(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			LA122_: ;
			T120_ = T121_;
			if (!(T120_)) goto LA123_;
			T120_ = ((*(*n).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47));
			LA123_: ;
			if (!T120_) goto LA124_;
			result = ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 1);
		}
		goto LA109_;
		LA124_: ;
		LA109_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T131_;
			if (!!(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA129_;
			T131_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T131_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
			result = isAssignable__H8ClJSBthN45fIRKmjWHMQ(owner, T131_, isUnsafeAddr);
		}
		LA129_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 143):
	{
		result = ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 1);
	}
	break;
	default:
	{
	}
	break;
	}
	return result;
}
static N_INLINE(NIM_BOOL, isRoutine__Ye2MiAptq3GrXxTQeyXNeAast)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((520192 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw, checkForSideEffects__apZ9c8Nt8WLADYEdQq9beFoA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw result;
{	result = (tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* op;
		op = (*n)._kind_6.sons->data[((NI) 0)];
		{
			NIM_BOOL T4_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
			T4_ = (NIM_BOOL)0;
			T4_ = ((*op).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T4_)) goto LA5_;
			T4_ = isRoutine__Ye2MiAptq3GrXxTQeyXNeAast((*op)._kind_4.sym);
			LA5_: ;
			if (!T4_) goto LA6_;
			s = (*op)._kind_4.sym;
			{
				if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 13))&63U)))!=0)) goto LA10_;
				result = ((tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw) 1);
				goto BeforeRet_;
			}
			LA10_: ;
			result = ((tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw) 2);
		}
		goto LA2_;
		LA6_: ;
		{
			if (!(((*(*op).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 1))&63U)))!=0)) goto LA13_;
			result = ((tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw) 2);
		}
		goto LA2_;
		LA13_: ;
		{
			result = ((tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw) 1);
			goto BeforeRet_;
		}
		LA2_: ;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw ret;
					if (!(i_2 < colontmp_)) goto LA18;
					i = i_2;
					ret = checkForSideEffects__apZ9c8Nt8WLADYEdQq9beFoA((*n)._kind_6.sons->data[i]);
					{
						if (!(ret == ((tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw) 1))) goto LA21_;
						result = ret;
						goto BeforeRet_;
					}
					goto LA19_;
					LA21_: ;
					{
						NIM_BOOL T24_;
						T24_ = (NIM_BOOL)0;
						T24_ = (ret == ((tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw) 0));
						if (!(T24_)) goto LA25_;
						T24_ = (result == ((tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw) 2));
						LA25_: ;
						if (!T24_) goto LA26_;
						result = ((tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw) 0);
					}
					goto LA19_;
					LA26_: ;
					LA19_: ;
					i_2 += ((NI) 1);
				} LA18: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	{
		result = ((tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw) 2);
	}
	break;
	default:
	{
		result = ((tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw) 2);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw ret_2;
					if (!(i_4 < colontmp__2)) goto LA32;
					i_3 = i_4;
					ret_2 = checkForSideEffects__apZ9c8Nt8WLADYEdQq9beFoA((*n)._kind_6.sons->data[i_3]);
					{
						if (!(ret_2 == ((tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw) 1))) goto LA35_;
						result = ret_2;
						goto BeforeRet_;
					}
					goto LA33_;
					LA35_: ;
					{
						NIM_BOOL T38_;
						T38_ = (NIM_BOOL)0;
						T38_ = (ret_2 == ((tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw) 0));
						if (!(T38_)) goto LA39_;
						T38_ = (result == ((tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw) 2));
						LA39_: ;
						if (!T38_) goto LA40_;
						result = ((tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw) 0);
					}
					goto LA33_;
					LA40_: ;
					LA33_: ;
					i_4 += ((NI) 1);
				} LA32: ;
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, matchNodeKinds__WRbpWXbxOP9c3ULW5bbDujw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	tyArray__zl3qUQvo0CT9bJi9b5H7mRkw stack;
	NI sp;
	NimStringDesc* code;
	NI pc;
	result = (NIM_BOOL)0;
	stack[(((NI) 0))- 0] = NIM_TRUE;
	sp = ((NI) 1);
	code = (*p)._kind_3.strVal;
	pc = ((NI) 1);
	{
		while (1) {
			switch (((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) (((NU8)(code->data[pc]))))) {
			case ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 1):
			{
				goto LA1;
			}
			break;
			case ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 2):
			{
				NIM_BOOL T5_;
				T5_ = (NIM_BOOL)0;
				T5_ = stack[((NI)(sp - ((NI) 1)))- 0];
				if (T5_) goto LA6_;
				T5_ = stack[((NI)(sp - ((NI) 2)))- 0];
				LA6_: ;
				stack[((NI)(sp - ((NI) 2)))- 0] = T5_;
				sp -= ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 3):
			{
				NIM_BOOL T8_;
				T8_ = (NIM_BOOL)0;
				T8_ = stack[((NI)(sp - ((NI) 1)))- 0];
				if (!(T8_)) goto LA9_;
				T8_ = stack[((NI)(sp - ((NI) 2)))- 0];
				LA9_: ;
				stack[((NI)(sp - ((NI) 2)))- 0] = T8_;
				sp -= ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 4):
			{
				stack[((NI)(sp - ((NI) 1)))- 0] = !(stack[((NI)(sp - ((NI) 1)))- 0]);
			}
			break;
			case ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 5):
			{
				stack[(sp)- 0] = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
				sp += ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 6):
			{
				stack[(sp)- 0] = isAtom__ORlI8o1EUYdPqjuTcBWx1Aast(n);
				sp += ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 7):
			{
				stack[(sp)- 0] = ((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23));
				sp += ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 8):
			{
				stack[(sp)- 0] = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
				sp += ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 9):
			{
				stack[(sp)- 0] = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
				sp += ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 10):
			{
				tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
				NIM_BOOL T17_;
				kind = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) (((NU8)(code->data[(NI)(pc + ((NI) 1))]))));
				T17_ = (NIM_BOOL)0;
				T17_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
				if (!(T17_)) goto LA18_;
				T17_ = ((*(*n)._kind_4.sym).kind == kind);
				LA18_: ;
				stack[(sp)- 0] = T17_;
				sp += ((NI) 1);
				pc += ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 11):
			{
				tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind_2;
				kind_2 = ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) (((NU8)(code->data[(NI)(pc + ((NI) 1))]))));
				stack[(sp)- 0] = ((*n).kind == kind_2);
				sp += ((NI) 1);
				pc += ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 12):
			{
				tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag T21_;
				T21_ = (tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag)0;
				T21_ = isAssignable__H8ClJSBthN45fIRKmjWHMQ(((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL), n, NIM_FALSE);
				stack[(sp)- 0] = ((6 &((NU8)1<<((NU)(T21_)&7U)))!=0);
				sp += ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 13):
			{
				tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag T23_;
				T23_ = (tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag)0;
				T23_ = isAssignable__H8ClJSBthN45fIRKmjWHMQ(((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL), n, NIM_FALSE);
				stack[(sp)- 0] = (T23_ == ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 2));
				sp += ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 14):
			{
				tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw T25_;
				T25_ = (tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw)0;
				T25_ = checkForSideEffects__apZ9c8Nt8WLADYEdQq9beFoA(n);
				stack[(sp)- 0] = (T25_ == ((tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw) 1));
				sp += ((NI) 1);
			}
			break;
			case ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 15):
			{
				tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw T27_;
				T27_ = (tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw)0;
				T27_ = checkForSideEffects__apZ9c8Nt8WLADYEdQq9beFoA(n);
				stack[(sp)- 0] = !((T27_ == ((tyEnum_TSideEffectAnalysis__39b55cGxMJkG5uRuPt6svRw) 1)));
				sp += ((NI) 1);
			}
			break;
			}
			pc += ((NI) 1);
		}
	} LA1: ;
	result = stack[((NI)(sp - ((NI) 1)))- 0];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isLValue__kCP6QlI8uS4X0pOQUdr7tg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag T1_;
	result = (NIM_BOOL)0;
	T1_ = (tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag)0;
	T1_ = isAssignable__H8ClJSBthN45fIRKmjWHMQ(((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL), n, NIM_FALSE);
	result = ((38 &((NU8)1<<((NU)(T1_)&7U)))!=0);
	return result;
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__i80o3k0SgEI5gTRCzYdyWAsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, patternError__5Tflpt1vZ7YgBe0KNn4aLw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	T1_ = (NimStringDesc*)0;
	T2_ = (NimStringDesc*)0;
	T2_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 4);
	T1_ = rawNewString((T2_ ? T2_->Sup.len : 0) + 15);
appendString(T1_, ((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_2));
appendString(T1_, T2_);
	liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T1_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__kdeXVhLeMhTeIyOxnAjnxA_3, NIM_FALSE);
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, add__wJRzZcEmnPNg9a3PLD2A5IAparampatterns)(NimStringDesc** code, tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA op) {
	unsureAsgnRef((void**) (&(*code)), addChar((*code), ((NIM_CHAR) (((NI) (op))))));
}
static N_INLINE(NimStringDesc*, toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = resizeString(result, (info.Field0 ? info.Field0->Sup.len : 0) + 0);
appendString(result, info.Field0);
	{
		if (!(((NI) 0) < info.Field1)) goto LA3_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_19));
		addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) (info.Field1)));
		{
			if (!(((NI) 0) < (NI)(info.Field2 + ((NI) 1)))) goto LA7_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_20));
			addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) ((NI)(info.Field2 + ((NI) 1)))));
		}
		LA7_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_21));
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, compileConstraints__ei3y5Hkw3H4CU1JGiutKlw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* p, NimStringDesc** result, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
{	switch ((*p).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* op;
		{
			if (!!(((*(*p)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2)))) goto LA4_;
			patternError__5Tflpt1vZ7YgBe0KNn4aLw((*p)._kind_6.sons->data[((NI) 0)], conf);
			goto BeforeRet_;
		}
		LA4_: ;
		op = (*(*p)._kind_6.sons->data[((NI) 0)])._kind_5.ident;
		{
			NI T8_;
			T8_ = (NI)0;
			T8_ = len__P89cqdlERShb9alU3iC0yj8wast(p);
			if (!(T8_ == ((NI) 3))) goto LA9_;
			{
				NIM_BOOL T13_;
				T13_ = (NIM_BOOL)0;
				T13_ = eqStrings((*op).s, ((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_5));
				if (T13_) goto LA14_;
				T13_ = ((*op).Sup.id == ((NI) 47));
				LA14_: ;
				if (!T13_) goto LA15_;
				compileConstraints__ei3y5Hkw3H4CU1JGiutKlw((*p)._kind_6.sons->data[((NI) 1)], result, conf);
				compileConstraints__ei3y5Hkw3H4CU1JGiutKlw((*p)._kind_6.sons->data[((NI) 2)], result, conf);
				add__wJRzZcEmnPNg9a3PLD2A5IAparampatterns(result, ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 2));
			}
			goto LA11_;
			LA15_: ;
			{
				NIM_BOOL T18_;
				T18_ = (NIM_BOOL)0;
				T18_ = eqStrings((*op).s, ((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_6));
				if (T18_) goto LA19_;
				T18_ = ((*op).Sup.id == ((NI) 2));
				LA19_: ;
				if (!T18_) goto LA20_;
				compileConstraints__ei3y5Hkw3H4CU1JGiutKlw((*p)._kind_6.sons->data[((NI) 1)], result, conf);
				compileConstraints__ei3y5Hkw3H4CU1JGiutKlw((*p)._kind_6.sons->data[((NI) 2)], result, conf);
				add__wJRzZcEmnPNg9a3PLD2A5IAparampatterns(result, ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 3));
			}
			goto LA11_;
			LA20_: ;
			{
				patternError__5Tflpt1vZ7YgBe0KNn4aLw(p, conf);
			}
			LA11_: ;
		}
		goto LA6_;
		LA9_: ;
		{
			NIM_BOOL T24_;
			NI T25_;
			NIM_BOOL T27_;
			T24_ = (NIM_BOOL)0;
			T25_ = (NI)0;
			T25_ = len__P89cqdlERShb9alU3iC0yj8wast(p);
			T24_ = (T25_ == ((NI) 2));
			if (!(T24_)) goto LA26_;
			T27_ = (NIM_BOOL)0;
			T27_ = eqStrings((*op).s, ((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_7));
			if (T27_) goto LA28_;
			T27_ = ((*op).Sup.id == ((NI) 43));
			LA28_: ;
			T24_ = T27_;
			LA26_: ;
			if (!T24_) goto LA29_;
			compileConstraints__ei3y5Hkw3H4CU1JGiutKlw((*p)._kind_6.sons->data[((NI) 1)], result, conf);
			add__wJRzZcEmnPNg9a3PLD2A5IAparampatterns(result, ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 4));
		}
		goto LA6_;
		LA29_: ;
		{
			patternError__5Tflpt1vZ7YgBe0KNn4aLw(p, conf);
		}
		LA6_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37):
	{
		{
			NI T35_;
			T35_ = (NI)0;
			T35_ = len__P89cqdlERShb9alU3iC0yj8wast(p);
			if (!(T35_ == ((NI) 1))) goto LA36_;
			compileConstraints__ei3y5Hkw3H4CU1JGiutKlw((*p)._kind_6.sons->data[((NI) 0)], result, conf);
		}
		goto LA33_;
		LA36_: ;
		{
			patternError__5Tflpt1vZ7YgBe0KNn4aLw(p, conf);
		}
		LA33_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	{
		NimStringDesc* spec;
		spec = nsuNormalize((*(*p)._kind_5.ident).s);
		switch (hashString(spec) & 15) {
		case 2: 
if (eqStrings(spec, ((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_18))) goto LA50_;
break;
		case 4: 
if (eqStrings(spec, ((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_10))) goto LA42_;
if (eqStrings(spec, ((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_15))) goto LA47_;
if (eqStrings(spec, ((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_17))) goto LA49_;
break;
		case 6: 
if (eqStrings(spec, ((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_11))) goto LA43_;
break;
		case 10: 
if (eqStrings(spec, ((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_14))) goto LA46_;
break;
		case 11: 
if (eqStrings(spec, ((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_8))) goto LA40_;
break;
		case 12: 
if (eqStrings(spec, ((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_9))) goto LA41_;
break;
		case 13: 
if (eqStrings(spec, ((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_12))) goto LA44_;
break;
		case 14: 
if (eqStrings(spec, ((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_13))) goto LA45_;
if (eqStrings(spec, ((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_16))) goto LA48_;
break;
		}
		goto LA51_;
		LA40_: ;
		{
			add__wJRzZcEmnPNg9a3PLD2A5IAparampatterns(result, ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 6));
		}
		goto LA52_;
		LA41_: ;
		{
			add__wJRzZcEmnPNg9a3PLD2A5IAparampatterns(result, ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 7));
		}
		goto LA52_;
		LA42_: ;
		{
			add__wJRzZcEmnPNg9a3PLD2A5IAparampatterns(result, ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 5));
		}
		goto LA52_;
		LA43_: ;
		{
			add__wJRzZcEmnPNg9a3PLD2A5IAparampatterns(result, ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 8));
		}
		goto LA52_;
		LA44_: ;
		{
			add__wJRzZcEmnPNg9a3PLD2A5IAparampatterns(result, ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 9));
		}
		goto LA52_;
		LA45_: ;
		{
			(*result)->data[((NI) 0)] = 2;
		}
		goto LA52_;
		LA46_: ;
		{
			(*result)->data[((NI) 0)] = 3;
		}
		goto LA52_;
		LA47_: ;
		{
			add__wJRzZcEmnPNg9a3PLD2A5IAparampatterns(result, ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 12));
		}
		goto LA52_;
		LA48_: ;
		{
			add__wJRzZcEmnPNg9a3PLD2A5IAparampatterns(result, ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 13));
		}
		goto LA52_;
		LA49_: ;
		{
			add__wJRzZcEmnPNg9a3PLD2A5IAparampatterns(result, ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 14));
		}
		goto LA52_;
		LA50_: ;
		{
			add__wJRzZcEmnPNg9a3PLD2A5IAparampatterns(result, ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 15));
		}
		goto LA52_;
		LA51_: ;
		{
			{
				NimStringDesc* argX60gensym13_;
				if (!NIM_FALSE) goto LA67_;
				argX60gensym13_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__kdeXVhLeMhTeIyOxnAjnxA_22);
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw(conf, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym13_, TM__kdeXVhLeMhTeIyOxnAjnxA_22);
			}
			LA67_: ;
			{
				tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw i;
				i = (tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw)0;
				{
					tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw v;
					NI res;
					v = (tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw)0;
					res = ((NI) 0);
					{
						while (1) {
							if (!(res <= ((NI) 25))) goto LA72;
							v = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) (res));
							i = v;
							{
								NimStringDesc* T75_;
								NI T76_;
								T75_ = (NimStringDesc*)0;
								T75_ = substr__iGg0RIKceRvsmvq8FUHOEw(reprEnum((NI)i, (&NTI__cNCW9acsSznmEccl1fgQwkw_)), ((NI) 2));
								T76_ = (NI)0;
								T76_ = nsuCmpIgnoreStyle(T75_, spec);
								if (!(T76_ == ((NI) 0))) goto LA77_;
								add__wJRzZcEmnPNg9a3PLD2A5IAparampatterns(result, ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 10));
								unsureAsgnRef((void**) (&(*result)), addChar((*result), ((NIM_CHAR) (((NI) (i))))));
								goto BeforeRet_;
							}
							LA77_: ;
							res += ((NI) 1);
						} LA72: ;
					}
				}
			}
			{
				NimStringDesc* argX60gensym15_;
				if (!NIM_FALSE) goto LA81_;
				argX60gensym15_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__kdeXVhLeMhTeIyOxnAjnxA_23);
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw(conf, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym15_, TM__kdeXVhLeMhTeIyOxnAjnxA_23);
			}
			LA81_: ;
			{
				tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw i_2;
				i_2 = (tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw)0;
				{
					tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw v_2;
					NI res_2;
					v_2 = (tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw)0;
					res_2 = ((NI) 0);
					{
						while (1) {
							if (!(res_2 <= ((NI) 160))) goto LA86;
							v_2 = ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) (res_2));
							i_2 = v_2;
							{
								NI T89_;
								T89_ = (NI)0;
								T89_ = nsuCmpIgnoreStyle(reprEnum((NI)i_2, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)), spec);
								if (!(T89_ == ((NI) 0))) goto LA90_;
								add__wJRzZcEmnPNg9a3PLD2A5IAparampatterns(result, ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 11));
								unsureAsgnRef((void**) (&(*result)), addChar((*result), ((NIM_CHAR) (((NI) (i_2))))));
								goto BeforeRet_;
							}
							LA90_: ;
							res_2 += ((NI) 1);
						} LA86: ;
					}
				}
			}
			patternError__5Tflpt1vZ7YgBe0KNn4aLw(p, conf);
		}
		LA52_: ;
	}
	break;
	default:
	{
		patternError__5Tflpt1vZ7YgBe0KNn4aLw(p, conf);
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semNodeKindConstraints__h4580wUcWriTu1bx3JdXfA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI start) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20), (*n).info);
	asgnRef((void**) (&(*result)._kind_3.strVal), rawNewString(((NI) 10)));
	asgnRef((void**) (&(*result)._kind_3.strVal), addChar((*result)._kind_3.strVal, 1));
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(((NI) 2) <= T3_)) goto LA4_;
		{
			NI i;
			NI colontmp_;
			NI T7_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T7_ = (NI)0;
			T7_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			colontmp_ = ((NI) (T7_));
			i_2 = start;
			{
				while (1) {
					if (!(((NI) (i_2)) < ((NI) (colontmp_)))) goto LA9;
					i = i_2;
					compileConstraints__ei3y5Hkw3H4CU1JGiutKlw((*n)._kind_6.sons->data[i], (&(*result)._kind_3.strVal), conf);
					i_2 += ((NI) 1);
				} LA9: ;
			}
		}
		{
			if (!(((NI) 63) < ((*result)._kind_3.strVal ? (*result)._kind_3.strVal->Sup.len : 0))) goto LA12_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw(conf, (*n).info, ((NimStringDesc*) &TM__kdeXVhLeMhTeIyOxnAjnxA_24), TM__kdeXVhLeMhTeIyOxnAjnxA_25);
		}
		LA12_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		patternError__5Tflpt1vZ7YgBe0KNn4aLw(n, conf);
	}
	LA1_: ;
	add__wJRzZcEmnPNg9a3PLD2A5IAparampatterns((&(*result)._kind_3.strVal), ((tyEnum_TOpcode__cKhgukabZvDBOVLlPOrptA) 1));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAliasRequest__BbWVl1Ad9ayM74eg8oBpAfw, whichAlias__L77p3t6SRXEDQrcmQOzgoA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* p) {
	tyEnum_TAliasRequest__BbWVl1Ad9ayM74eg8oBpAfw result;
	result = (tyEnum_TAliasRequest__BbWVl1Ad9ayM74eg8oBpAfw)0;
	{
		if (!!(((*p).constraint == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA3_;
		result = ((tyEnum_TAliasRequest__BbWVl1Ad9ayM74eg8oBpAfw) (((NU8)((*(*p).constraint)._kind_3.strVal->data[((NI) 0)]))));
	}
	goto LA1_;
	LA3_: ;
	{
		result = ((tyEnum_TAliasRequest__BbWVl1Ad9ayM74eg8oBpAfw) 1);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, exprRoot__XD7qSmhHQJchscUPfXW57g)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	it = n;
	{
		while (1) {
			switch ((*it).kind) {
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
			{
				result = (*it)._kind_4.sym;
				goto BeforeRet_;
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47):
			{
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T7_;
					T7_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T7_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*it)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273744));
					if (!((6291456 &((NU64)1<<((NU)((*T7_).kind)&63U)))!=0)) goto LA8_;
					goto LA1;
				}
				goto LA5_;
				LA8_: ;
				{
					it = (*it)._kind_6.sons->data[((NI) 0)];
				}
				LA5_: ;
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 67):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46):
			{
				it = (*it)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 60):
			{
				it = (*it)._kind_6.sons->data[((NI) 1)];
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126):
			{
				{
					NIM_BOOL T16_;
					NI T17_;
					T16_ = (NIM_BOOL)0;
					T17_ = (NI)0;
					T17_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
					T16_ = (((NI) 0) < T17_);
					if (!(T16_)) goto LA18_;
					T16_ = !(((*it).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
					LA18_: ;
					if (!T16_) goto LA19_;
					it = lastSon__UPSW0jLTX5qJL51YMUAHgw(it);
				}
				goto LA14_;
				LA19_: ;
				{
					goto LA1;
				}
				LA14_: ;
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
			{
				{
					NIM_BOOL T25_;
					NIM_BOOL T26_;
					NI T29_;
					T25_ = (NIM_BOOL)0;
					T26_ = (NIM_BOOL)0;
					T26_ = !(((*it).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
					if (!(T26_)) goto LA27_;
					T26_ = ((IL64(140737496743936) &((NU64)1<<((NU)((*(*it).typ).kind)&63U)))!=0);
					LA27_: ;
					T25_ = T26_;
					if (!(T25_)) goto LA28_;
					T29_ = (NI)0;
					T29_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
					T25_ = (((NI) 1) < T29_);
					LA28_: ;
					if (!T25_) goto LA30_;
					it = (*it)._kind_6.sons->data[((NI) 1)];
				}
				goto LA23_;
				LA30_: ;
				{
					goto LA1;
				}
				LA23_: ;
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		}
	} LA1: ;
	}BeforeRet_: ;
	return result;
}
